@@ -4,7 +4,7 @@
 # can do whatever you want with this stuff. If we meet some day, and you think
 # this stuff is worth it, you can buy me a beer in return.   Anton Berezin
 # ----------------------------------------------------------------------------
-# Copyright (c) 2005-2012 SPARTA, Inc.
+# Copyright (c) 2005-2009 SPARTA, Inc.
 # All rights reserved.
 #  
 # Redistribution and use in source and binary forms, with or without
@@ -33,7 +33,7 @@
 # OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 # ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #
-# $Id: Fast.pm 6903 2012-06-21 20:10:13Z hardaker $
+# $Id: Fast.pm 4353 2009-02-06 20:57:28Z hardaker $
 #
 package Net::DNS::ZoneFile::Fast;
 # documentation at the __END__ of the file
@@ -46,23 +46,16 @@ use Net::DNS;
 use Net::DNS::RR;
 use MIME::Base64;
 
-$VERSION = '1.16';
+$VERSION = '1.1';
 
 my $MAXIMUM_TTL = 0x7fffffff;
 
-my $pat_ttl = qr{\d+[\dwdhms]*}i;
+my $pat_ttl = qr{[\dwdhms]+}i;
 my $pat_skip = qr{\s*(?:;.*)?};
-my $pat_name = qr{[-\*\w\$\d\/*]+(?:\.[-\*\w\$\d\/]+)*};
+my $pat_name = qr{[-\w\$\d\/*]+(?:\.[-\w\$\d\/]+)*};
+my $pat_maybefullname = qr{[-\w\$\d\/*]+(?:\.[-\w\$\d\/]+)*\.?};
 my $pat_maybefullnameorroot = qr{(?:\.|[-\w\$\d\/*]+(?:\.[-\w\$\d\/]+)*\.?)};
 
-#
-# Added the ability to have a backslash in the SOA username.  This is to
-# provide for the RFC-allowed "Joe\.Jones.example.com" construct to allow
-# dots in usernames.  Keeping the original version here for easy reference.
-#
-# my $pat_maybefullname = qr{[-\w\$\d\/*]+(?:\.[-\w\$\d\/]+)*\.?};
-my $pat_maybefullname   = qr{[-\w\$\d\/*\\]+(?:\.[-\w\$\d\/]+)*\.?};
-
 my $debug;
 my $domain;
 my $parse;
@@ -75,7 +68,6 @@ my @zone;
 my $soa;
 my $rrsig;
 my $sshfp;
-my $key;
 my $dnskey;
 my $ds;
 my $on_error;
@@ -88,7 +80,7 @@ my $includes_root;
 my $globalerror;
 my $nsec3capable;
 
-# boot strap optional DNSSEC module functions
+# boot strap optional DNSSEC module functcions
 # (not optional if trying to parse a signed zone, but we don't need
 # these modules unless we are.
 $nsec3capable = eval {
@@ -202,11 +194,7 @@ sub parse
 	    Net::DNS::RR->new_from_hash(%$z);
 
 	  if ($newrec->{'type'} eq 'DNSKEY') {
-	      if (ref($newrec) ne 'Net::DNS::RR::DNSKEY') {
-		  warn "Failed to define a DNSSEC object (got: " . ref($newrec) . "); you're probably missing either MIME::Base64 or MIME::Base32";
-	      } else {
-		  $newrec->setkeytag;
-	      }
+	      $newrec->setkeytag;
 	  }
 
 	  # no longer an issue with recent Net::DNS
@@ -286,13 +274,13 @@ sub parse_line
 	  	error("\$GENERATE pattern without a wildcard") if $pat !~ /\$/;
 	  	while ($from <= $to) {
 	  		$_ = $pat;
-	  		s{\$ (?:\{ ([\d+-]+) (?:, (\d+) (?:, ([doxX]) )? )? \})?}
+	  		s{\$ (?:\{ (\d+) (?:, (\d+) (?:, ([doxX]) )? )? \})?}
 	  			{
 	  				my ($offset, $width, $base) = ($1, $2, $3);
 	  				$offset ||= 0;
 	  				$width  ||= 0;
 	  				$base   ||= 'd';
-	  				sprintf "%0$width$base", $offset + $from;
+	  				sprintf "%$width$base", $offset + $from;
 	  			}xge;
 	  		$parse->();
 	  		$from++;
@@ -585,13 +573,12 @@ sub parse_line
 		 };
 	  $parse->();
 	  return;
-      } elsif (/\G(txt|spf)[ \t]+/igc) {
-	  my $type = uc($1);
+      } elsif (/\G(txt)[ \t]+/igc) {
 	  if (/\G('[^']+')$pat_skip$/gc) {
 	      push @zone, {
 			   Line    => $ln,
 			   name    => $domain,
-			   type    => $type,
+			   type    => "TXT",
 			   ttl     => $ttl,
 			   class   => "IN",
 			   txtdata => $1,
@@ -600,7 +587,7 @@ sub parse_line
 	      push @zone, {
 			   Line    => $ln,
 			   name    => $domain,
-			   type    => $type,
+			   type    => "TXT",
 			   ttl     => $ttl,
 			   class   => "IN",
 			   txtdata => $1,
@@ -609,40 +596,13 @@ sub parse_line
 	      push @zone, {
 			   Line    => $ln,
 			   name    => $domain,
-			   type    => $type,
+			   type    => "TXT",
 			   ttl     => $ttl,
 			   class   => "IN",
 			   txtdata => $1,
 			  };
 	  } else {
-	      error("bad txtdata in $type");
-	  }
-      } elsif (/\G(type[0-9]+)[ \t]+/igc) {
-          my $type = $1;
-	  if (/\G\\#\s+(\d+)\s+\(\s(.*)$/gc) {
-	      # multi-line
-	      $sshfp = { 
-			Line    => $ln,
-			name    => $domain,
-			type    => uc $type,
-			ttl     => $ttl,
-			class   => "IN",
-                        fptype  => $1,
-			fingerprint => $2,
-		       };
-	      $parse = \&parse_sshfp;
-	  } elsif (/\G\\#\s+(\d+)\s+(.*)$pat_skip$/gc) {
-	      push @zone, {
-			   Line    => $ln,
-			   name    => $domain,
-			   type    => uc $type,
-			   ttl     => $ttl,
-			   class   => "IN",
-                           fptype  => $1,
-			   fingerprint => $2,
-			  };
-	  } else {
-	      error("bad data in in $type");
+	      error("bad txtdata in TXT");
 	  }
       } elsif (/\G(sshfp)[ \t]+/igc) {
 	  if (/\G(\d+)\s+(\d+)\s+\(\s*$/gc) {
@@ -657,7 +617,7 @@ sub parse_line
 			fptype => $2,
 		       };
 	      $parse = \&parse_sshfp;
-	  } elsif (/\G(\d+)\s+(\d+)\s+([a-zA-Z0-9]+)$pat_skip$/gc) {
+	  } elsif (/\G(\d+)\s+(\d+)\s+(.*)$pat_skip$/gc) {
 	      push @zone, {
 			   Line    => $ln,
 			   name    => $domain,
@@ -733,8 +693,9 @@ sub parse_line
 	      error("bad LOC data");
 	  }
       } elsif (/\G(hinfo)[ \t]+/igc) {
-	  if (/\G(["'].*?["']|\S+)\s+(["'].*?["']|\S+)$pat_skip$/gc) {
-	      my $result = {
+	  # parsing stolen from Net::DNS::RR::HINFO
+	  if (/\G["'](.*?)["']\s+["'](.*?)["']$pat_skip$/gc) {
+	      push @zone, {
 			   Line      => $ln,
 			   name      => $domain,
 			   type      => "HINFO",
@@ -743,11 +704,6 @@ sub parse_line
 			   cpu       => $1,
 			   os        => $2,
 			  };
-	      $result->{'cpu'} =~ s/^["']//;
-	      $result->{'cpu'} =~ s/["']$//;
-	      $result->{'os'} =~ s/^["']//;
-	      $result->{'os'} =~ s/["']$//;
-	      push @zone, $result;
 	  } else {
 	      error("bad HINFO data");
 	  }
@@ -769,35 +725,6 @@ sub parse_line
 	  } else {
 	      error("bad SRV data");
 	  }
-      } elsif (/\G(key)[ \t]+/igc) {
-	  if (!/\G(\d+)\s+(\d+)\s+(\d+)\s+/gc) {
-	      error("bad KEY data 1");
-	  }
-	  $dnskey = {
-		     first     => 1,
-		     Line      => $ln,
-		     name      => $domain,
-		     ttl       => $ttl,
-		     class     => "IN",
-		     type      => "KEY",
-		     flags     => $1,
-		     protocol  => $2,
-		     algorithm => $3
-		    };
-	  if (/\G\(\s*$/gc) {
-	      # multi-line
-	      $parse = \&parse_dnskey;
-	  } elsif (/\G(.*\S)\s*$/) {
-	      # single-line
-	      $dnskey->{'key'} .= $1;
-	      $dnskey->{'key'} =~ s/\s//g;
-	      $dnskey->{'keybin'} = decode_base64($dnskey->{'key'});
-	      push @zone, $dnskey;
-	      $dnskey = undef;
-	  } else {
-	      error("bad KEY data 2");
-	  }
-
       } elsif (/\G(rrsig)[ \t]+/igc) {
 	  if (!/\G(\w+)\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)\s+/gc) {
 	      error("bad RRSIG data 1");
@@ -818,7 +745,7 @@ sub parse_line
 	  if (/\G\(\s*$/gc) {
 	      # multi-line
 	      $parse = \&parse_rrsig;
-	  } elsif (/\G(\d+)\s+(\d+)\s+($pat_maybefullnameorroot)\s+([^=]+=)\s*/gc) {
+	  } elsif (/\G(\d+)\s+(\d+)\s+($pat_maybefullname)\s+([^=]+=)\s*/gc) {
 	      # single-line
 	      $rrsig->{'siginception'} = $1;
 	      $rrsig->{'keytag'} = $2;
@@ -848,7 +775,7 @@ sub parse_line
 	  if (/\G\(\s*$/gc) {
 	      # multi-line
 	      $parse = \&parse_dnskey;
-	  } elsif (/\G([\sA-Za-z0-9\+\/=]+).*$/) {
+	  } elsif (/\G(.*\S)\s*$/) {
 	      # single-line
 	      $dnskey->{'key'} .= $1;
 	      $dnskey->{'key'} =~ s/\s//g;
@@ -879,10 +806,6 @@ sub parse_line
 	      # single line
 	      $ds->{'digest'} .= $1;
 	      $ds->{'digest'} = lc($ds->{'digest'});
-	      $ds->{'digest'} =~ s/\s//g;
-	      # remove any surrounding single line ()s
-	      $ds->{'digest'} =~ s/^\(//;
-	      $ds->{'digest'} =~ s/\)$//;
 	      $ds->{'digestbin'} = pack("H*", $ds->{'digest'});
 	      push @zone, $ds;
 	      $ds = undef;
@@ -890,12 +813,10 @@ sub parse_line
 	      error("bad DS data");
 	  }
       } elsif (/\G(nsec)[ \t]+/igc) {
-	  if (/\G\s*($pat_maybefullnameorroot)\s+(.*?)$pat_skip$/gc) {
+	  if (/\G\s*($pat_maybefullname)\s+(.*)$pat_skip$/gc) {
 	      # XXX: set the typebm field ourselves?
 	      my ($nxtdname, $typelist) = ($1, $2);
 	      $typelist = join(" ",sort split(/\s+/,$typelist));
-	      print STDERR "**************************************** here: $nxtdname";
-	      exit;
 	      push @zone, 
 		{
 		 Line      => $ln,
@@ -903,7 +824,7 @@ sub parse_line
 		 class     => "IN",
 		 ttl       => $ttl,
 		 type      => "NSEC",
-		 nxtdname  => lc($nxtdname),
+		 nxtdname  => $nxtdname,
 		 typelist  => $typelist,
 		 typebm    =>
 		 Net::DNS::RR::NSEC::_typearray2typebm(split(/\s+/,$typelist)),
@@ -914,7 +835,7 @@ sub parse_line
       } elsif (/\G(nsec3)[ \t]+/igc) {
 	  error ("You are missing required modules for NSEC3 support")
 	    if (!$nsec3capable);
-	  if (/\G\s*(\d+)\s+(\d+)\s+(\d+)\s+([-0-9A-Fa-f]+)\s+($pat_maybefullname)\s+(.*?)$pat_skip$/gc) {
+	  if (/\G\s*(\d+)\s+(\d+)\s+(\d+)\s+([-0-9A-Fa-f]+)\s+($pat_maybefullname)\s+(.*)$pat_skip$/gc) {
 	      # XXX: set the typebm field ourselves?
 	      my ($alg, $flags, $iters, $salt, $nxthash, $typelist) =
 		($1, $2, $3, $4, $5, $6);
@@ -1024,7 +945,7 @@ sub parse_line
       } elsif (/\Gany\s+tsig.*$/igc) {
 	  # XXX ignore tsigs
       } else {
-	  error("unrecognized type for $domain\n$_\n");
+	  error("unrecognized type");
       }
   }
 
@@ -1106,7 +1027,7 @@ sub parse_rrsig
       # got more data
       if ($rrsig->{'first'}) {
 	  delete $rrsig->{'first'};
-	  if (/\G\s*(\d+)\s+(\d+)\s+($pat_maybefullnameorroot)/gc) {
+	  if (/\G\s*(\d+)\s+(\d+)\s+($pat_maybefullname)/gc) {
 	      $rrsig->{'siginception'} = $1;
 	      $rrsig->{'keytag'} = $2;
 	      $rrsig->{'signame'} = $3;
@@ -1254,10 +1175,8 @@ sub parse_soa_number
 	  }
 	  delete $soa->{nextkey};
 	  delete $soa->{breakable};
-          $soa->{mname} .= $origin unless ($soa->{mname} =~ /\.$/);
-          $soa->{rname} .= $origin unless ($soa->{rname} =~ /\.$/);
-	  $soa->{mname} =~ s/\.$//;
-	  $soa->{rname} =~ s/\.$//;
+	  chop $soa->{mname};
+	  chop $soa->{rname};
 	  $soa->{Lines} = $ln - $soa->{Line} + 1;
 	  push @zone, $soa;
 	  $soa = undef;
@@ -1446,7 +1365,7 @@ unless B<on_error> is also specified, in which case it is true.
 =item B<includes_root>
 
 An optional parameter.  By default, any $INCLUDE directives encountered
-will be tested for existence and readability.  If the base path of the
+will be tested for existance and readablility.  If the base path of the
 included filename is not your current working directory, this test will
 fail.  Set the B<includes_root> to the same as your named.conf file to
 avoid this failure.
@@ -1487,7 +1406,7 @@ either via hash lookup (C<$rr-E<gt>{Line}>), or via an accessor method
 
 =head1 BUGS
 
-The I<parse()> subroutine is not re-entrant, and it probably will never be.
+The I<parse()> subroutine is not re-entrant.  Plobably will never be.
 
 There is also no guarantee that I<parse()> will successfully parse every
 zone parsable by BIND, and no guarantee that BIND will parse every zone
@@ -1509,7 +1428,7 @@ Copyright 2003 by Anton Berezin and catpipe Systems ApS
 
   Anton Berezin
 
-Copyright (c) 2004-2012 SPARTA, Inc.
+Copyright (c) 2004-2008 SPARTA, Inc.
   All rights reserved.
    
   Redistribution and use in source and binary forms, with or without
@@ -1541,7 +1460,7 @@ Copyright (c) 2004-2012 SPARTA, Inc.
 =head1 CREDITS
 
 Anton Berezin created the versions up until 0.5.  Wes Hardaker at
-Sparta implemented the DNSSEC patches and took over maintenance of the
+Sparta implemented the DNSSEC patches and took over maintaince of the
 module from 0.6 onward.
 
 Anton's original CREDITS section:
