@@ -1,5 +1,5 @@
 #
-# Copyright 2006-2012 SPARTA, Inc.  All rights reserved.  See the COPYING
+# Copyright 2006-2009 SPARTA, Inc.  All rights reserved.  See the COPYING
 # file distributed with this software for details
 #
 # DNSSEC Tools
@@ -22,8 +22,7 @@ use Net::DNS::SEC::Tools::defaults;
 use Net::DNS::SEC::Tools::keyrec;
 use Net::DNS::SEC::Tools::rollrec;
 
-our $VERSION = "1.13";
-our $MODULE_VERSION = "1.13.0";
+our $VERSION = "0.9";
 
 our @ISA = qw(Exporter);
 
@@ -38,40 +37,33 @@ our @EXPORT = qw(
 #
 my %dtcmds =
 (
-	'blinkenlights'	   => 1,
-	'cleanarch'	   => 1,
-	'cleankrf'	   => 1,
-	'dtconf'	   => 1,
-	'dtconfchk'	   => 1,
-	'dtdefs'	   => 1,
-	'dtinitconf'	   => 1,
-	'dtrealms'	   => 1,
-	'expchk'	   => 1,
-	'fixkrf'	   => 1,
-	'genkrf'	   => 1,
-	'getdnskeys'	   => 1,
-	'grandvizier'	   => 1,
-	'keyarch'	   => 1,
-	'krfcheck'	   => 1,
-	'lsdnssec'	   => 1,
-	'lskrf'		   => 1,
-	'lsrealm'	   => 1,
-	'lsroll'	   => 1,
-	'realmchk'	   => 1,
-	'realmctl'	   => 1,
-	'realminit'	   => 1,
-	'rollchk'	   => 1,
-	'rollctl'	   => 1,
-	'rollerd'	   => 1,
-	'rollinit'	   => 1,
-	'rolllog'	   => 1,
-	'rollrec-editor'   => 1,
-	'rollset'	   => 1,
-	'signset-editor'   => 1,
-	'tachk'		   => 1,
-	'timetrans'	   => 1,
-	'trustman'	   => 1,
-	'zonesigner'	   => 1,
+	"blinkenlights"	   => 1,
+	"cleanarch"	   => 1,
+	"cleankrf"	   => 1,
+	"dtconf"	   => 1,
+	"dtconfchk"	   => 1,
+	"dtdefs"	   => 1,
+	"dtinitconf"	   => 1,
+	"expchk"	   => 1,
+	"fixkrf"	   => 1,
+	"genkrf"	   => 1,
+	"getdnskeys"	   => 1,
+	"keyarch"	   => 1,
+	"krfcheck"	   => 1,
+	"lskrf"		   => 1,
+	"lsroll"	   => 1,
+	"rollchk"	   => 1,
+	"rollctl"	   => 1,
+	"rollerd"	   => 1,
+	"rollinit"	   => 1,
+	"rolllog"	   => 1,
+	"rollrec-editor"   => 1,
+	"rollset"	   => 1,
+	"signset-editor"   => 1,
+	"tachk"		   => 1,
+	"timetrans"	   => 1,
+	"trustman"	   => 1,
+	"zonesigner"	   => 1,
 );
 
 #-----------------------------------------------------------------------------
@@ -91,7 +83,6 @@ sub dt_adminmail
 	my $mh;					# Mail handler.
 
 	my %dtconf;				# DNSSEC-Tools config file.
-	my @mailargs;
 
 	#
 	# Get the message recipient.  If the caller didn't specify one,
@@ -116,11 +107,6 @@ sub dt_adminmail
 	#
 	return(0) if($sendto eq "");
 
-	#
-	# If things are configured to not send email, we'll return success.
-	#
-	return(1) if($sendto eq "nomail");
-
 	#
 	# Create the message object.
 	#
@@ -133,23 +119,15 @@ sub dt_adminmail
 	$msg->subject($subject);
 
 	#
-	# Open the "connection" and add the message body.
+	# Add the message body.
 	#
-	push @mailargs, $dtconf{'mailer-type'}
-		if(defined($dtconf{'mailer-type'}));
-	push @mailargs, 'smtp'
-		if(!defined($dtconf{'mailer-type'}) &&
-		    defined($dtconf{'mailer-server'}));
-	push @mailargs, Server => $dtconf{'mailer-server'}
-		if(defined($dtconf{'mailer-server'}));
-
-	eval { $mh = $msg->open(@mailargs); }; return(0) if $@;
+	$mh = $msg->open;
 	print $mh $msgbody . "\n";
 
 	#
 	# Complete the message and send it.
 	#
-	eval { $mh->close; }; return(0) if $@;
+	$mh->close;
 	return(1);
 }
 
@@ -294,35 +272,12 @@ The I<msgbody> parameter is the body of the mail message.
 A third parameter, I<recipient>, may be given to specify the message's
 recipient.  If this is not given, then the recipient will be taken from
 the I<admin-email> record of the DNSSEC-Tools configuration file.
-If I<recipient> is "nomail", then no message will be sent and success
-will be returned.
 
 Return values:
 
 	1 - the message was created and sent.
 	0 - an invalid recipient was specified. 
 
-=back
-
-It relies on the the following dnssec-tools.conf configuration parameters:
-
-=over 4
-
-=item I<admin-email>
-
-The email address that the mail should come from.
-
-=item I<mailer-type>
-
-Should be one of: I<sendmail, smtp, qmail>.  This option is not
-required and will default to trying sendmail and qmail to deliever the
-mail.  If I<mailer-server> is set to a defined value but I<mailer-type> is not, then I<mailer-type> will default to 
-
-=item I<mailer-server>
-
-The server, if I<admin-mail> is set to I<smtp>, that the mail should
-be delivered to.
-
 =item I<dt_cmdpath(command)>
 
 This routine returns the path to a specified DNSSEC-Tools command.
@@ -361,12 +316,12 @@ Return values:
 
 =head1 COPYRIGHT
 
-Copyright 2006-2012 SPARTA, Inc.  All rights reserved.
+Copyright 2006-2009 SPARTA, Inc.  All rights reserved.
 See the COPYING file included with the DNSSEC-Tools package for details.
 
 =head1 AUTHOR
 
-Wayne Morrison, tewok@tislabs.com
+Wayne Morrison, tewok@users.sourceforge.net
 
 =head1 SEE ALSO
 
@@ -375,7 +330,3 @@ B<Net::DNS::SEC::Tools::conf.pm(3)>
 
 =cut
 
-# Local Variables:
-# tab-width: 4
-# cperl-indent-level: 4
-# End:
