@@ -1,5 +1,5 @@
 #
-# Copyright 2005-2012 SPARTA, Inc.  All rights reserved.  See the COPYING
+# Copyright 2005-2009 SPARTA, Inc.  All rights reserved.  See the COPYING
 # file distributed with this software for details
 #
 # DNSSEC Tools
@@ -20,8 +20,7 @@ use Socket;
 use Net::DNS::SEC::Tools::conf;
 use Net::DNS::SEC::Tools::defaults;
 
-our $VERSION = "1.13";
-our $MODULE_VERSION = "1.13.0";
+our $VERSION = "0.91";
 
 our @ISA = qw(Exporter);
 
@@ -33,8 +32,6 @@ our @EXPORT = qw(
 		 rolllog_level
 		 rolllog_levels
 		 rolllog_num
-		 rolllog_gettz
-		 rolllog_settz
 		 rolllog_str
 			 LOG_NEVER
 			 LOG_TMI
@@ -95,9 +92,6 @@ my @logstrs =					# Valid strings for levels.
 
 my $logfile;					# rollerd's log file.
 
-my $DEFAULT_LOGTZ = 'gmt';			# Default timezone.
-my $usetz = $DEFAULT_LOGTZ;			# Timezone selector to use.
-
 
 
 ##############################################################################
@@ -214,59 +208,6 @@ sub rolllog_levels
 	return(@levels);
 }
 
-##############################################################################
-#
-# Routine:	rolllog_gettz()
-#
-# Purpose:	Return the timezone function used for timestamps in log
-#		messages.  'local' and 'gmt' are the acceptable values.
-#
-sub rolllog_gettz
-{
-	#
-	# If the logging timezone hasn't been set yet, we'll set it to
-	# the default value
-	#
-	if($usetz eq '')
-	{
-		$usetz = $DEFAULT_LOGTZ;
-	}
-
-	return($usetz);
-}
-
-##############################################################################
-#
-# Routine:	rolllog_settz()
-#
-# Purpose:	Set the timezone selector to use for timestamps in log
-#		messages.  'local' and 'gmt' are the acceptable values.
-#
-sub rolllog_settz
-{
-	my $newtz = shift;				# New timezone.
-	my $oldtz = $usetz;				# Old timezone.
-
-	#
-	# Ensure a valid timezone selector was given.  If no selector
-	# was given, then we'll use the default.
-	#
-	if($newtz ne '')
-	{
-		return('') if(($newtz !~ /^gmt$/i) && ($newtz !~ /^local$/i));
-	}
-	else
-	{
-		$newtz = dnssec_tools_default('log_tz');
-	}
-
-	#
-	# Set the timezone selector and return the old selector.
-	#
-	$usetz = lc $newtz;
-	return($oldtz);
-}
-
 ##############################################################################
 #
 # Routine:	rolllog_str()
@@ -469,14 +410,7 @@ sub rolllog_log
 	#
 	# Get the timestamp.
 	#
-	if($usetz eq 'local')
-	{
-		$kronos = localtime();
-	}
-	else
-	{
-		$kronos = gmtime();
-	}
+	$kronos = gmtime();
 	$kronos =~ s/^....//;
 
 	#
@@ -524,9 +458,6 @@ Net::DNS::SEC::Tools::rolllog - DNSSEC-Tools rollover logging interfaces.
   $bool = rolllog_validlevel($newlevel);
   $bool = rolllog_validlevel(8);
 
-  $curtz = rolllog_gettz();
-  $oldtz = rolllog_settz('local');
-
   rolllog_log(LOG_INFO,"example.com","zone is valid");
 
 =head1 DESCRIPTION
@@ -559,22 +490,10 @@ recorded.
 
 =over 4
 
-=item I<rolllog_file(newfile,useflag)>
+=item I<rolllog_levels()>
 
-This routine sets and retrieves the log file for B<rollerd>.
-The I<newfile> argument specifies the new log file to be set.  If I<newfile>
-exists, it must be a regular file.
-
-The I<useflag> argument is a boolean that indicates whether or not to give a
-descriptive message if an invalid log file is given.  If I<useflag> is
-true, the message is given and the process exits; if false, no message is
-given.  For any error condition, an empty string is returned.
-
-=item I<rolllog_gettz()>
-
-This routine returns the timezone selector currently in use.  This value may
-be either 'gmt' (for Greenwich Mean Time) or 'local' (for the host's local
-time.)
+This routine returns an array holding the text forms of the user-settable
+logging levels.  The levels are returned in order, from most verbose to least.
 
 =item I<rolllog_level(newlevel,useflag)>
 
@@ -591,10 +510,34 @@ If given with no arguments, the current logging level is returned.  In fact,
 the current level is always returned unless an error is found.  -1 is returned
 on error.
 
-=item I<rolllog_levels()>
+=item I<rolllog_file(newfile,useflag)>
 
-This routine returns an array holding the text forms of the user-settable
-logging levels.  The levels are returned in order, from most verbose to least.
+This routine sets and retrieves the log file for B<rollerd>.
+The I<newfile> argument specifies the new log file to be set.  If I<newfile>
+exists, it must be a regular file.
+
+The I<useflag> argument is a boolean that indicates whether or not to give a
+descriptive message if an invalid logging level is given.  If I<useflag> is
+true, the message is given and the process exits; if false, no message is
+given.  For any error condition, an empty string is returned.
+
+=item I<rolllog_num(loglevel)>
+
+This routine translates a text log level (given in I<loglevel>) into the
+associated numeric log level.  The numeric log level is returned to the caller.
+
+If I<loglevel> is an invalid log level, -1 is returned.
+
+=item I<rolllog_str(loglevel)>
+
+This routine translates a log level (given in I<loglevel>) into the associated
+text log level.  The text log level is returned to the caller.
+
+If I<loglevel> is a text string, it is checked to ensure it is a valid log
+level.  Case is irrelevant when checking I<loglevel>.
+
+If I<loglevel> is numeric, it is must be in the valid range of log levels.
+I<undef> is returned if I<loglevel> is invalid.
 
 =item I<rolllog_log(level,group,message)>
 
@@ -613,35 +556,6 @@ B<rollerd> to group messages by the zone to which the message applies.
 The I<message> argument is the log message itself.  Trailing newlines are
 removed.
 
-=item I<rolllog_num(loglevel)>
-
-This routine translates a text log level (given in I<loglevel>) into the
-associated numeric log level.  The numeric log level is returned to the caller.
-
-If I<loglevel> is an invalid log level, -1 is returned.
-
-=item I<rolllog_settz(tzsel)>
-
-This routine sets the timezone to be used for timestamps in messages written
-to the log.  This I<tzsel> value may be either 'gmt' (Greenwich Mean Time)
-or 'local' (for the host's local time.)  I<tzsel> may be uppercase or
-lowercase; the value will be converted to lowercase.  If no value is passed,
-then the default will be used.
-
-The current timezone selector is returned.  If an invalid selector is given,
-then an undefined value is returned.
-
-=item I<rolllog_str(loglevel)>
-
-This routine translates a log level (given in I<loglevel>) into the associated
-text log level.  The text log level is returned to the caller.
-
-If I<loglevel> is a text string, it is checked to ensure it is a valid log
-level.  Case is irrelevant when checking I<loglevel>.
-
-If I<loglevel> is numeric, it is must be in the valid range of log levels.
-I<undef> is returned if I<loglevel> is invalid.
-
 =item I<rolllog_validlevel(level)>
 
 This interface returns a boolean value indicating if the given logging level
@@ -654,12 +568,12 @@ numeric or textual value.
 
 =head1 COPYRIGHT
 
-Copyright 2005-2012 SPARTA, Inc.  All rights reserved.
+Copyright 2005-2009 SPARTA, Inc.  All rights reserved.
 See the COPYING file included with the DNSSEC-Tools package for details.
 
 =head1 AUTHOR
 
-Wayne Morrison, tewok@tislabs.com
+Wayne Morrison, tewok@users.sourceforge.net
 
 =head1 SEE ALSO
 
