@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# Copyright 2005-2012 SPARTA, Inc.  All rights reserved.  See the COPYING
+# Copyright 2005-2009 SPARTA, Inc.  All rights reserved.  See the COPYING
 # file distributed with this software for details.
 #
 # DNSSEC-Tools
@@ -27,13 +27,11 @@ use strict;
 use Net::DNS::SEC::Tools::conf;
 use Net::DNS::SEC::Tools::keyrec;
 
-our $VERSION = "1.13";
-our $MODULE_VERSION = "1.13.0";
+our $VERSION = "0.9";
 
 our @ISA = qw(Exporter);
 
 our @EXPORT = qw(
-			opts_cmdline
 			opts_cmdopts
 			opts_createkrf
 			opts_drop
@@ -66,12 +64,10 @@ my @stdopts =
 		["random=s",		"Random number generator device"],
 		["endtime=s",		"End-time for signed zone"],
 		["gends",		"Generate DS records"],
-		["nogends",		"Don't generate DS records"],
 
 	'',
 
 	['GUI:separator',	'Configuration Options:'],
-		["dtconfig=s",		"DNSSEC-Tools configuration file"],
 		["keyrec=s",		"Keyrec name",
 		  helpdesc => 'test'
 		],
@@ -90,8 +86,6 @@ my @stdopts =
 		["kskdirectory=s",	"Directory for KSK keys"],
 		["ksklength=i",		"Length of KSK"],
 		["ksklife=i",		"Life-span of KSK"],
-		["revperiod=i",		"Revocation period"],
-		["dsdir=s",		"Directory for dsset files"],
 		["ksdir=s",		"Directory for keyset files"],
 
 	'',
@@ -124,9 +118,7 @@ my @stdopts =
 	['GUI:separator',	'Roll-over Options:'],
 		["roll_logfile=s",	"Roll-over manager's log filename"],
 		["roll_loglevel=s",	"Roll-over manager's logging level"],
-		["logtz=s",		"Roll-over manager's logging timezone"],
 		["roll_sleeptime=i",	"Sleep-time for Roll-over manager"],
-		["zone_errors=i",	"Maximum consecutive errors for a zone"],
 
 	'',
 
@@ -301,9 +293,14 @@ sub opts_zonekr
 	%optionset = dnssec_tools_alldefaults();
 
 	#
-	# Get the config file contents.
+	# Get the config file and mix the file contents in with the defaults.
+	#
 	#
 	%subopts = parseconfig();
+	foreach my $k (sort(keys(%subopts)))
+	{
+		$optionset{$k} = $subopts{$k};
+	}
 
 	#
 	# Set the GUI-usage flag according to the config file.  This must be
@@ -312,27 +309,10 @@ sub opts_zonekr
 	$gui = $optionset{'usegui'};
 
 	#
-	# Get the command-line options.
+	# Mix in the command-line options with all the others.
 	#
 	%cmdopts = opts_int_cmdline(@csopts);
 
-	#
-	# If the user specified a different config file, we'll parse it.
-	#
-	if(defined($cmdopts{'dtconfig'}))
-	{
-		setconffile($cmdopts{'dtconfig'});
-		%subopts = parseconfig();
-	}
-
-	#
-	# Mix the config file contents in with the defaults.
-	#
-	foreach my $k (sort(keys(%subopts)))
-	{
-		$optionset{$k} = $subopts{$k};
-	}
-
 	#
 	# Get the keyrec file (from command line options) and keyrec name
 	# (from command line args) values if the caller didn't give them.
@@ -342,8 +322,8 @@ sub opts_zonekr
 	$krname = $cmdopts{'zone'}	if(defined($cmdopts{'zone'}));
 
 	#
-	# Initialize (maybe) and read the keyrec file and the specified zone,
-	# putting the data into a hash table.
+	# Initialize and read the keyrec file and the specified zone.
+	# We'll only read the 
 	#
 	$optionset{'krfile'} = $krfile;
 	if($krfile ne "")
@@ -578,7 +558,6 @@ sub opts_int_zonecopy
 	#
 	# Read the keyrec file.
 	#
-	keyrec_close();
 	keyrec_read($krfile);
 
 # print "\nopts_int_zonecopy:  down in\n";
@@ -631,11 +610,7 @@ sub opts_int_zonecopy
 	#
 	# Return failure if there's no zone keyrec.
 	#
-	if(!$found)
-	{
-		keyrec_close();
-		return(undef);
-	}
+	return(undef) if(!$found);
 
 	#
 	# Get the zone's keyrec values.
@@ -655,8 +630,7 @@ sub opts_int_zonecopy
 	#
 	# Copy the data from the Current KSK and Current ZSK keyrecs.
 	#
-#	foreach my $ktype ('kskcur', 'zskcur')
-	foreach my $ktype ('kskcur', 'zskcur', 'kskpub', 'zskpub', 'zsknew')
+	foreach my $ktype ('kskcur', 'zskcur')
 	{
 		my $setname;			# Name of the signing set.
 		my $setkeys;			# Keys in the signing set.
@@ -695,63 +669,6 @@ sub opts_int_zonecopy
 	return(%fields);
 }
 
-##############################################################################
-# Routine:	opts_cmdline()
-#
-# Purpose:	Parse a command line looking for the arguments in the standard
-#		set of options and the caller's set.  If the first argument is
-#		true, the program-wide @ARGV is restored after parsing.  If the
-#		caller provides other arguments, they're added as additional
-#		options.  The parsed options are returned to the caller.
-#
-sub opts_cmdline
-{
-	my $saveargv = shift;			# Flag for saving @ARGV.
-	my @csopts = @_;			# Command-specific options.
-
-	my @args;				# Copy of @ARGV.
-	my @opts;				# Copy of standard options.
-	my %parsedopts;				# Parsed options.
-
-	my $curgui = $gui;			# Saved $gui value.
-	my $curfc = $firstcall;			# Saved $firstcall value.
-
-	#
-	# Save the argument vector.
-	#
-	@args = @ARGV;
-
-	#
-	# Add the standard options to the caller's options.
-	#
-	@opts = @stdopts;
-	push @opts, @csopts if(@csopts > 0);
-
-	#
-	# Force some flags we need.
-	#
-	$gui = 0;
-	$firstcall = 0;
-
-	#
-	# Extract the command line options.
-	#
-	localgetoptions(\%parsedopts,@opts);
-
-	#
-	# Restore the forced flags.
-	#
-	$gui = $curgui;
-	$firstcall = $curfc;
-
-	#
-	# Restore the saved argument vector.
-	#
-	@ARGV = @args if($saveargv);
-
-	return(%parsedopts);
-}
-
 ##############################################################################
 #
 sub opts_int_cmdline
@@ -889,8 +806,6 @@ Net::DNS::SEC::Tools::tooloptions - DNSSEC-Tools option routines.
 
   @specopts = ("propagate+", "waittime=i");
 
-  %opts = opts_cmdline($restoreargv,@calleropts);
-
   $optsref = opts_cmdopts(@specopts);
   %options = %$optsref;
 
@@ -986,12 +901,12 @@ A reference to the hash table created in these steps is returned to the caller.
 B<dnssec-tools.conf> has these entries:
 
     ksklength      2048
-    zsklength      1024
+    zsklength      512
 
 B<example.keyrec> has this entry:
 
     key         "Kexample.com.+005+12345"
-            zsklength        "2048"
+            zsklength        "1024"
 
 B<zonesigner> is executed with this command line:
 
@@ -999,7 +914,7 @@ B<zonesigner> is executed with this command line:
 
 I<opts_zonekr("example.keyrec","Kexample.com.+005+12345",("wait=i"))>
 will read each option source in turn, ending up with:
-    I<ksklength>          1024
+    I<ksklength>           512
     I<zsklength>          4096
     I<wait>                600
 
@@ -1007,17 +922,9 @@ will read each option source in turn, ending up with:
 
 =over 4
 
-=item I<opts_cmdline($restoreargv,@calleropts)>
-
-This routine parses a command line looking for the arguments in the standard
-set of options and an optional set of options specified by the caller.  If the
-first argument is true, the program-wide @ARGV is restored after parsing.  If
-the caller provides other arguments, they're added as additional options.  The
-parsed options are returned to the caller in a hash.
-
 =item I<opts_cmdopts(@csopts)>
 
-The I<opts_cmdopts()> call builds an option hash from the system configuration
+This I<opts_cmdopts()> call builds an option hash from the system configuration
 file, a I<keyrec>, and a set of command-specific options.  A reference to
 this option hash is returned to the caller.
 
@@ -1040,9 +947,6 @@ folded in as well, but the key's I<keyrec_> fields are excluded.  This
 call ensures that the named I<keyrec> is a zone I<keyrec>; if it isn't,
 I<undef> is returned.
 
-The I<keyrec> file is read with I<keyrec_read()>.  To ensure it is properly
-read, I<keyrec_close()> is called first.
-
 The I<$keyrec_file> argument specifies a I<keyrec> file that will be
 consulted.  The I<keyrec> named by the I<$keyrec_name> argument will be
 loaded.  If a I<keyrec> file is found and I<opts_createkrf()> has been
@@ -1056,10 +960,6 @@ taken from I<$ARGV[0]>.
 The I<@specopts> array contains command-specific arguments; the arguments must
 be in the format prescribed by the B<Getopt::Long> Perl module.
 
-If the command line contains the I<-dtconfig> option, then I<opts_zonekr>()
-sets that option to be the configuration file.  It then parses that file and
-uses it as the source for configuration file data.
-
 =item I<opts_setcsopts(@csopts)>
 
 This routine saves a copy of the command-specific options given in I<@csopts>.
@@ -1096,7 +996,7 @@ modified by the calling program itself.
 =item I<opts_gui()>
 
 Set an internal flag so that command arguments may be specified with a GUI.
-GUI usage requires that B<Getopt::GUI::Long> is available.  If it isn't, then
+GUI usage requires that B<Getopt::Long::GUI> is available.  If it isn't, then 
 B<Getopt::Long> will be used.
 
 =item I<opts_nogui()>
@@ -1117,12 +1017,12 @@ The old exit action is returned.
 
 =head1 COPYRIGHT
 
-Copyright 2005-2012 SPARTA, Inc.  All rights reserved.
+Copyright 2005-2009 SPARTA, Inc.  All rights reserved.
 See the COPYING file included with the DNSSEC-Tools package for details.
 
 =head1 AUTHOR
 
-Wayne Morrison, tewok@tislabs.com
+Wayne Morrison, tewok@users.sourceforge.net
 
 =head1 SEE ALSO
 
